@@ -1,10 +1,10 @@
 import git
 import click
 
-from gitutor.init.commands import init
-from gitutor.save.commands import save
-from gitutor.ignore.commands import ignore
-from gitutor.compare.commands import compare
+from init.commands import init
+from save.commands import save
+from ignore.commands import ignore
+from compare.commands import compare
 
 @click.group()
 @click.pass_context
